[−][src]Crate libevent_sys
Raw Rust bindings to the libevent C library.
Bindings are generated with Rust-Bindgen which means there are a number of quirks.
- Enums are a constants in the form of
enum_name_ENUM_FIELD - Functions are named the same as the C code and don't follow Rust naming schemes.
- Uses C strings. See
CStrin the Rust standard library.
Structs
Constants
Statics
| _IO_2_1_stdin_ | |
| _IO_2_1_stdout_ | |
| _IO_2_1_stderr_ | |
| __daylight | |
| __timezone | |
| __tzname | |
| daylight | |
| in6addr_any | |
| in6addr_loopback | |
| stderr | |
| stdin | |
| stdout | |
| sys_errlist | |
| sys_nerr | |
| timezone | |
| tzname |